@@ -14,24 +14,30 @@ static void xsystem(const char *command)
 		errp("system(%s) failed", command);
 }
 
-static void xsystembash(const char *command)
+static void xsystembash(const char *command, int cwd)
 {
 	pid_t p = vfork();
 	int status;
 
 	switch (p) {
 	case 0: /* child */
+		if (cwd != AT_FDCWD)
+			if (fchdir(cwd))
+				errp("fchdir failed");
 		execl("/bin/bash", "bash", "--norc", "--noprofile", "-c", command, NULL);
 		/* Hrm, still here ?  Maybe no bash ... */
 		_exit(execl("/bin/sh", "sh", "-c", command, NULL));
 
 	default: /* parent */
 		waitpid(p, &status, 0);
-		if (WIFEXITED(status)) {
+		if (WIFSIGNALED(status)) {
+			err("phase crashed with signal %i: %s", WTERMSIG(status),
+			    strsignal(WTERMSIG(status)));
+		} else if (WIFEXITED(status)) {
 			if (WEXITSTATUS(status) == 0)
 				return;
 			else
-				exit(WEXITSTATUS(status));
+				err("phase exited %i", WEXITSTATUS(status));
 		}
 		/* fall through */
 
